@@ -236,6 +236,9 @@ function configure_trove {
     iniset $TROVE_CONF DEFAULT taskmanager_manager trove.taskmanager.manager.Manager
     iniset $TROVE_CONF DEFAULT default_datastore $TROVE_DATASTORE_TYPE
 
+    iniset $TROVE_CONF cache enabled true
+    iniset $TROVE_CONF cache backend dogpile.cache.memory
+
     iniset $TROVE_CONF cassandra tcp_ports 7000,7001,7199,9042,9160
     iniset $TROVE_CONF couchbase tcp_ports 8091,8092,4369,11209-11211,21100-21199
     iniset $TROVE_CONF couchdb tcp_ports 5984
@@ -269,6 +272,11 @@ function configure_trove {
     iniset $TROVE_GUESTAGENT_CONF service_credentials region_name $REGION_NAME
     iniset $TROVE_GUESTAGENT_CONF service_credentials auth_url $TROVE_AUTH_ENDPOINT
 
+    iniset $TROVE_GUESTAGENT_CONF mysql docker_image ${TROVE_DATABASE_IMAGE_MYSQL}
+    iniset $TROVE_GUESTAGENT_CONF mysql backup_docker_image ${TROVE_DATABASE_BACKUP_IMAGE_MYSQL}
+    iniset $TROVE_GUESTAGENT_CONF postgresql docker_image ${TROVE_DATABASE_IMAGE_POSTGRES}
+    iniset $TROVE_GUESTAGENT_CONF postgresql backup_docker_image ${TROVE_DATABASE_BACKUP_IMAGE_POSTGRES}
+
     # 1. To avoid 'Connection timed out' error of sudo command inside the guest agent
     # 2. Config the controller IP address used by guest-agent to download Trove code during initialization (only valid for dev_mode=true).
     common_cloudinit=/etc/trove/cloudinit/common.cloudinit
