@@ -112,6 +112,9 @@ common_opts = [
                help='Service type to use when searching catalog.'),
     cfg.StrOpt('glance_endpoint_type', default='publicURL',
                help='Service endpoint type to use when searching catalog.'),
+    cfg.StrOpt('taskmanager_manager',
+               default='trove.taskmanager.manager.Manager',
+               help='Driver for taskmanager'),
     cfg.StrOpt('trove_url', help='URL without the tenant segment.'),
     cfg.StrOpt('trove_service_type', default='database',
                help='Service type to use when searching catalog.'),
@@ -1088,13 +1091,18 @@ postgresql_group = cfg.OptGroup(
     'postgresql', title='PostgreSQL options',
     help="Oslo option group for the PostgreSQL datastore.")
 postgresql_opts = [
+    cfg.BoolOpt(
+        'enable_clean_wal_archives',
+        default=True,
+        help='Enable the periodic job to clean up WAL archive folder.'
+    ),
     cfg.StrOpt(
         'docker_image', default='postgres',
         help='Database docker image.'
     ),
     cfg.StrOpt(
         'backup_docker_image',
-        default='openstacktrove/db-backup-postgresql:1.1.0',
+        default='openstacktrove/db-backup-postgresql:1.1.2',
         help='The docker image used for backup and restore.'
     ),
     cfg.BoolOpt('icmp', default=False,
@@ -1128,7 +1136,11 @@ postgresql_opts = [
     cfg.StrOpt('wal_archive_location', default='/mnt/wal_archive',
                help="Filesystem path storing WAL archive files when "
                     "WAL-shipping based backups or replication "
-                    "is enabled."),
+                    "is enabled.",
+               deprecated_for_removal=True,
+               deprecated_reason='Option is not used any more, will be '
+                                 'removed in future release.'
+               ),
     cfg.BoolOpt('root_on_create', default=False,
                 help='Enable the automatic creation of the root user for the '
                 'service during instance-create. The generated password for '
@@ -1151,7 +1163,7 @@ postgresql_opts = [
                     "statement logging.",
                deprecated_for_removal=True,
                deprecated_reason='Will be replaced by configuration group '
-               'option: log_min_duration_statement'),
+                                 'option: log_min_duration_statement'),
     cfg.IntOpt('default_password_length', default=36,
                help='Character length of generated passwords.',
                deprecated_name='default_password_length',
@@ -1574,6 +1586,7 @@ def list_opts():
         (None, path_opts + versions_opts + common_opts),
         ('database', database_opts),
         (mysql_group, mysql_opts),
+        (postgresql_group, postgresql_opts),
         (mariadb_group, mariadb_opts),
         (network_group, network_opts),
         (service_credentials_group, service_credentials_opts),
