@@ -15,6 +15,7 @@
 
 
 from oslo_config import cfg
+from oslo_policy import opts
 from oslo_policy import policy
 
 from trove.common import exception as trove_exceptions
@@ -23,6 +24,12 @@ from trove.common import policies
 CONF = cfg.CONF
 _ENFORCER = None
 
+# TODO(gmann): Remove setting the default value of config policy_file
+# once oslo_policy change the default value to 'policy.yaml'.
+# https://github.com/openstack/oslo.policy/blob/a626ad12fe5a3abd49d70e3e5b95589d279ab578/oslo_policy/opts.py#L49
+DEFAULT_POLICY_FILE = 'policy.yaml'
+opts.set_defaults(CONF, DEFAULT_POLICY_FILE)
+
 
 def get_enforcer():
     global _ENFORCER
