@@ -324,6 +324,7 @@ class Controller(object):
             exception.ModuleAppliedToInstance,
             exception.PolicyNotAuthorized,
             exception.LogAccessForbidden,
+            exception.TroveOperationAuthError,
         ],
         webob.exc.HTTPBadRequest: [
             exception.InvalidModelError,
@@ -368,7 +369,8 @@ class Controller(object):
             exception.LocalStorageNotSupported,
             exception.DatastoreOperationNotSupported,
             exception.ClusterInstanceOperationNotSupported,
-            exception.ClusterDatastoreNotSupported
+            exception.ClusterDatastoreNotSupported,
+            exception.LogsNotAvailable
         ],
     }
 
