@@ -64,7 +64,15 @@ class Manager(periodic_task.PeriodicTasks):
 
     MODULE_APPLY_TO_ALL = module_manager.ModuleManager.MODULE_APPLY_TO_ALL
 
-    docker_client = docker.from_env()
+    _docker_client = None
+
+    @property
+    def docker_client(self):
+        if self._docker_client:
+            return self._docker_client
+
+        self._docker_client = docker.from_env()
+        return self._docker_client
 
     def __init__(self, manager_name):
         super(Manager, self).__init__(CONF)
@@ -88,6 +96,17 @@ class Manager(periodic_task.PeriodicTasks):
         self.app = None
         self.status = None
 
+        if CONF.guest_agent.container_registry:
+            try:
+                self.docker_client.login(
+                    CONF.guest_agent.container_registry_username,
+                    CONF.guest_agent.container_registry_password,
+                    email="",
+                    registry=CONF.guest_agent.container_registry)
+            except Exception as exc:
+                raise exception.GuestError(f"Failed to login the container "
+                                           f"registry, error: {str(exc)}")
+
     @property
     def manager_name(self):
         """This returns the passed-in name of the manager."""
@@ -317,6 +336,10 @@ class Manager(periodic_task.PeriodicTasks):
         pass
 
     def start_db_with_conf_changes(self, context, config_contents, ds_version):
+        """Start the database with given configuration.
+
+        This method is called after resize.
+        """
         self.app.start_db_with_conf_changes(config_contents, ds_version)
 
     def stop_db(self, context):
@@ -381,15 +404,17 @@ class Manager(periodic_task.PeriodicTasks):
     # Configuration
     ###############
     def reset_configuration(self, context, configuration):
-        """The default implementation should be sufficient if a
+        """Reset database base configuration.
+
+        The default implementation should be sufficient if a
         configuration_manager is provided. Even if one is not, this
         method needs to be implemented to allow the rollback of
         flavor-resize on the guestagent side.
         """
-        LOG.info("Resetting configuration.")
         if self.configuration_manager:
+            LOG.info("Resetting configuration.")
             config_contents = configuration['config_contents']
-            self.configuration_manager.save_configuration(config_contents)
+            self.configuration_manager.reset_configuration(config_contents)
 
     def apply_overrides_on_prepare(self, context, overrides):
         self.update_overrides(context, overrides)
@@ -760,6 +785,12 @@ class Manager(periodic_task.PeriodicTasks):
         LOG.info("Starting to restore database from backup %s, "
                  "backup_info: %s", backup_info['id'], backup_info)
 
+        if (backup_info["location"].endswith('.enc') and
+                not CONF.backup_aes_cbc_key):
+            self.status.set_status(service_status.ServiceStatuses.FAILED)
+            raise exception.TroveError('Decryption key not configured for '
+                                       'encrypted backup.')
+
         try:
             self.app.restore_backup(context, backup_info, restore_location)
         except Exception:
