@@ -55,10 +55,10 @@ from trove.common.notification import TroveInstanceCreate
 from trove.common.notification import TroveInstanceModifyFlavor
 from trove.common.strategies.cluster import strategy
 from trove.common.utils import try_recover
+from trove.configuration import models as config_models
 from trove.extensions.mysql import models as mysql_models
 from trove.instance import models as inst_models
 from trove.instance import service_status as srvstatus
-from trove.instance.models import BuiltInstance
 from trove.instance.models import DBInstance
 from trove.instance.models import FreshInstance
 from trove.instance.models import Instance
@@ -982,13 +982,12 @@ class FreshInstanceTasks(FreshInstance, NotifyMixin, ConfigurationMixin):
         metadata = {'trove_project_id': self.tenant_id,
                     'trove_user_id': self.context.user,
                     'trove_instance_id': self.id}
-        name = self.hostname or self.name
         bdmap_v2 = block_device_mapping_v2
         config_drive = CONF.use_nova_server_config_drive
         key_name = CONF.nova_keypair
 
         server = self.nova_client.servers.create(
-            name, image_id, flavor_id, key_name=key_name, nics=nics,
+            self.name, image_id, flavor_id, key_name=key_name, nics=nics,
             block_device_mapping_v2=bdmap_v2,
             files=files, userdata=userdata,
             availability_zone=availability_zone,
@@ -1094,7 +1093,7 @@ class FreshInstanceTasks(FreshInstance, NotifyMixin, ConfigurationMixin):
         return sg_id
 
 
-class BuiltInstanceTasks(BuiltInstance, NotifyMixin, ConfigurationMixin):
+class BuiltInstanceTasks(Instance, NotifyMixin, ConfigurationMixin):
     """
     BuiltInstanceTasks contains the tasks related an instance that already
     associated with a compute server.
@@ -1194,7 +1193,7 @@ class BuiltInstanceTasks(BuiltInstance, NotifyMixin, ConfigurationMixin):
                 self.reset_task_status()
 
     def attach_replica(self, master, restart=False):
-        LOG.info("Attaching replica %s to master %s", self.id, master.id)
+        LOG.info("Attaching replica %s to primary %s", self.id, master.id)
         try:
             replica_info = master.guest.get_replica_context()
             flavor = self.nova_client.flavors.get(self.flavor_id)
@@ -1730,9 +1729,14 @@ class ResizeVolumeAction(object):
             def volume_is_new_size():
                 volume = self.instance.volume_client.volumes.get(
                     self.instance.volume_id)
-                return volume.size == self.new_size
+                LOG.debug(f'Waiting for volume available, '
+                          f'id: {volume.id}, status: {volume.status}, '
+                          f'size: {volume.size}')
+                return (volume.size == self.new_size and
+                        volume.status in ['available', 'in-use'])
 
             utils.poll_until(volume_is_new_size,
+                             initial_delay=5,
                              sleep_time=5,
                              time_out=CONF.volume_time_out)
 
@@ -1852,15 +1856,17 @@ class ResizeActionBase(object):
         pass
 
     def _assert_datastore_is_ok(self):
+        LOG.info(f"Re-config database for instance {self.instance.id} after "
+                 f"resize")
         self._start_datastore()
 
     def _assert_processes_are_ok(self):
         """Checks the procs; if anything is wrong, reverts the operation."""
         # Tell the guest to turn back on, and make sure it can start.
+        LOG.info(f"Waiting for database status changed after resizing "
+                 f"{self.instance.id}")
         self._assert_guest_is_ok()
-        LOG.debug("Nova guest is ok.")
         self._assert_datastore_is_ok()
-        LOG.debug("Datastore is ok.")
 
     def _confirm_nova_action(self):
         LOG.debug("Instance %s calling Compute confirm resize...",
@@ -1889,7 +1895,7 @@ class ResizeActionBase(object):
     def execute(self):
         """Initiates the action."""
         try:
-            LOG.debug("Instance %s calling stop_db...", self.instance.id)
+            LOG.info(f"Stopping database service for {self.instance.id}")
             self.instance.guest.stop_db(do_not_start_on_reboot=True)
         except Exception as e:
             if self.ignore_stop_error:
@@ -1923,25 +1929,17 @@ class ResizeActionBase(object):
 
     def _perform_nova_action(self):
         """Calls Nova to resize or migrate an instance, and confirms."""
-        LOG.debug("Begin resize method _perform_nova_action instance: %s",
-                  self.instance.id)
         need_to_revert = False
         try:
-            LOG.debug("Initiating nova action")
             self._initiate_nova_action()
-            LOG.debug("Waiting for nova action completed")
             self._wait_for_nova_action()
-            LOG.debug("Asserting nova status is ok")
             self._assert_nova_status_is_ok()
             need_to_revert = True
-            LOG.debug("Asserting nova action success")
             self._assert_nova_action_was_successful()
-            LOG.debug("Asserting processes are OK")
             self._assert_processes_are_ok()
-            LOG.debug("Confirming nova action")
             self._confirm_nova_action()
         except Exception:
-            LOG.exception("Exception during nova action.")
+            LOG.exception(f"Failed to resize instance {self.instance.id}")
             if need_to_revert:
                 LOG.error("Reverting action for instance %s",
                           self.instance.id)
@@ -1949,13 +1947,12 @@ class ResizeActionBase(object):
                 self._wait_for_revert_nova_action()
 
             if self.instance.server_status_matches(['ACTIVE']):
-                LOG.error("Restarting datastore.")
+                LOG.error(f"Restarting instance {self.instance.id}")
                 self.instance.guest.restart()
             else:
-                LOG.error("Cannot restart datastore because "
-                          "Nova server status is not ACTIVE")
+                LOG.error(f"Cannot restart instance {self.instance.id} "
+                          f"because Nova server status is not ACTIVE")
 
-            LOG.error("Error resizing instance %s.", self.instance.id)
             raise
 
         self._record_action_success()
@@ -1963,8 +1960,8 @@ class ResizeActionBase(object):
                   self.instance.id)
 
     def _wait_for_nova_action(self):
-        LOG.info(f"Waiting for Nova server status changed to "
-                 f"{self.wait_status}")
+        LOG.debug(f"Waiting for Nova server status changed to "
+                  f"{self.wait_status} for {self.instance.id}")
 
         def update_server_info():
             self.instance.refresh_compute_server_info()
@@ -2010,6 +2007,7 @@ class ResizeAction(ResizeActionBase):
             raise TroveError(msg)
 
     def _initiate_nova_action(self):
+        LOG.info(f"Resizing Nova server for instance {self.instance.id}")
         self.instance.server.resize(self.new_flavor_id)
 
     def _revert_nova_action(self):
@@ -2073,6 +2071,11 @@ class MigrateAction(ResizeActionBase):
 
 class RebuildAction(ResizeActionBase):
     def __init__(self, instance, image_id):
+        """The action to perform rebuild.
+
+        :param instance: A BuiltInstanceTasks instance.
+        :param image_id: Image ID.
+        """
         super(RebuildAction, self).__init__(instance)
         self.image_id = image_id
         self.ignore_stop_error = True
@@ -2083,7 +2086,7 @@ class RebuildAction(ResizeActionBase):
             self.instance.datastore.name,
             self.instance.datastore_version.name)
 
-        LOG.debug(f"Rebuilding Nova server {self.instance.server.id}")
+        LOG.info(f"Rebuilding Nova server for instance {self.instance.id}")
         # Before Nova version 2.57, userdata is not supported when doing
         # rebuild, have to use injected files instead.
         self.instance.server.rebuild(
@@ -2102,23 +2105,47 @@ class RebuildAction(ResizeActionBase):
 
     def _assert_processes_are_ok(self):
         """Send rebuild async request to the guest and wait."""
+        context = self.instance.context
         flavor = self.instance.nova_client.flavors.get(self.instance.flavor_id)
         config = self.instance._render_config(flavor)
         config_contents = config.config_contents
 
         overrides = {}
         if self.instance.configuration:
-            overrides = self.instance.configuration. \
-                get_configuration_overrides()
+            user_config = config_models.Configuration(
+                context, self.instance.configuration.id)
+            overrides = user_config.get_configuration_overrides()
 
         LOG.info(f"Sending rebuild request to the instance {self.instance.id}")
         self.instance.guest.rebuild(
             self.instance.datastore_version.version,
             config_contents=config_contents, config_overrides=overrides)
 
-        LOG.info(f"Waiting for instance {self.instance.id} healthy")
+        LOG.info(f"Waiting for instance {self.instance.id} healthy after "
+                 f"rebuild")
         self._assert_guest_is_ok()
         self.wait_for_healthy()
+
+        # Restore replication config for primary
+        if self.instance.slaves:
+            LOG.info(f"Enabling {self.instance.id} as primay after rebuild")
+            self.instance.enable_as_master()
+
+            # Restart all the replicas to reconnect with the primary
+            for replica in self.instance.slaves:
+                LOG.info(f"Restarting replica {replica.id} after rebuild "
+                         f"primary {self.instance.id}")
+                replica_tasks = BuiltInstanceTasks.load(context, replica.id)
+                replica_tasks.restart()
+
+        # Restore replication config for replica
+        elif self.instance.slave_of_id:
+            LOG.info(f"Re-attaching replica {self.instance.id} after rebuild")
+            primary = BuiltInstanceTasks.load(
+                context, self.instance.slave_of_id)
+            self.instance.detach_replica(primary, for_failover=True)
+            self.instance.attach_replica(primary, restart=True)
+
         LOG.info(f"Finished to rebuild {self.instance.id}")
 
     def _revert_nova_action(self):
