@@ -195,7 +195,7 @@ class CheckInstance(AttrCheck):
         if 'flavor' not in self.instance:
             self.fail("'flavor' not found in instance.")
         else:
-            allowed_attrs = ['id']
+            allowed_attrs = ['id', 'links']
             self.contains_allowed_attrs(
                 self.instance['flavor'], allowed_attrs,
                 msg="Flavor")
@@ -204,7 +204,7 @@ class CheckInstance(AttrCheck):
         if 'datastore' not in self.instance:
             self.fail("'datastore' not found in instance.")
         else:
-            allowed_attrs = ['type', 'version']
+            allowed_attrs = ['type', 'version', 'version_number']
             self.contains_allowed_attrs(
                 self.instance['datastore'], allowed_attrs,
                 msg="datastore")
@@ -622,7 +622,7 @@ class CreateInstanceFail(object):
                              'server_state_description', 'status', 'updated',
                              'users', 'volume', 'root_enabled_at',
                              'root_enabled_by', 'fault',
-                             'service_status_updated']
+                             'service_status_updated', 'operating_status']
             with CheckInstance(result._info) as check:
                 check.contains_allowed_attrs(
                     result._info, allowed_attrs,
@@ -714,18 +714,13 @@ class CreateInstanceFail(object):
         users = []
         datastore = CONFIG.dbaas_datastore
         datastore_version = "nonexistent"
-        try:
-            assert_raises(exceptions.NotFound,
-                          dbaas.instances.create, instance_name,
-                          instance_info.dbaas_flavor_href,
-                          volume, databases, users,
-                          datastore=datastore,
-                          datastore_version=datastore_version,
-                          nics=instance_info.nics)
-        except exceptions.BadRequest as e:
-            assert_equal(e.message,
-                         "Datastore version '%s' cannot be found." %
-                         datastore_version)
+        assert_raises(exceptions.BadRequest,
+                      dbaas.instances.create, instance_name,
+                      instance_info.dbaas_flavor_href,
+                      volume, databases, users,
+                      datastore=datastore,
+                      datastore_version=datastore_version,
+                      nics=instance_info.nics)
 
 
 @test(
@@ -790,7 +785,8 @@ class CreateInstance(object):
         # Check these attrs only are returned in create response
         allowed_attrs = ['created', 'flavor', 'addresses', 'id', 'links',
                          'name', 'status', 'updated', 'datastore', 'fault',
-                         'region', 'service_status_updated', 'access']
+                         'region', 'service_status_updated', 'access',
+                         'operating_status']
         if ROOT_ON_CREATE:
             allowed_attrs.append('password')
         if VOLUME_SUPPORT:
@@ -933,7 +929,7 @@ class TestGetInstances(object):
     def test_index_list(self):
         allowed_attrs = ['id', 'links', 'name', 'status', 'flavor',
                          'datastore', 'ip', 'hostname', 'replica_of',
-                         'region', 'addresses', 'access']
+                         'region', 'addresses', 'access', 'operating_status']
         if VOLUME_SUPPORT:
             allowed_attrs.append('volume')
         instances = dbaas.instances.list()
@@ -955,7 +951,8 @@ class TestGetInstances(object):
         allowed_attrs = ['created', 'databases', 'flavor', 'hostname', 'id',
                          'links', 'name', 'status', 'updated', 'ip',
                          'datastore', 'fault', 'region',
-                         'service_status_updated', 'addresses', 'access']
+                         'service_status_updated', 'addresses', 'access',
+                         'operating_status']
         if VOLUME_SUPPORT:
             allowed_attrs.append('volume')
         instances = dbaas.instances.list(detailed=True)
@@ -975,7 +972,8 @@ class TestGetInstances(object):
         allowed_attrs = ['created', 'databases', 'flavor', 'hostname', 'id',
                          'links', 'name', 'status', 'updated', 'ip',
                          'datastore', 'fault', 'region',
-                         'service_status_updated', 'addresses', 'access']
+                         'service_status_updated', 'addresses', 'access',
+                         'operating_status']
         if VOLUME_SUPPORT:
             allowed_attrs.append('volume')
         else:
@@ -1055,7 +1053,7 @@ class TestGetInstances(object):
                          'name', 'root_enabled_at', 'root_enabled_by',
                          'server_state_description', 'status', 'datastore',
                          'updated', 'users', 'volume', 'fault', 'region',
-                         'access']
+                         'access', 'operating_status']
         with CheckInstance(result._info) as check:
             check.contains_allowed_attrs(
                 result._info, allowed_attrs,
