@@ -176,7 +176,7 @@ class BackupCreateTest(trove_testtools.TestCase):
                               BACKUP_NAME, BACKUP_DESC)
 
     def test_create_backup_swift_token_invalid(self):
-        instance = MagicMock()
+        instance = MagicMock(cluster_id=None)
         with patch.object(instance_models.BuiltInstance, 'load',
                           return_value=instance):
             instance.validate_can_perform_action = MagicMock(
@@ -191,7 +191,7 @@ class BackupCreateTest(trove_testtools.TestCase):
                                       BACKUP_NAME, BACKUP_DESC)
 
     def test_create_backup_datastore_operation_not_supported(self):
-        instance = MagicMock()
+        instance = MagicMock(cluster_id=None)
         with patch.object(instance_models.BuiltInstance, 'load',
                           return_value=instance):
             with patch.object(
@@ -547,7 +547,7 @@ class OrderingTests(trove_testtools.TestCase):
         backups, marker = models.Backup.list(self.context)
         self.assertIsNone(marker)
         actual = [b.name for b in backups]
-        expected = [u'one', u'two', u'three', u'four']
+        expected = ['one', 'two', 'three', 'four']
         self.assertEqual(expected, actual)
 
     def test_list_for_instance(self):
@@ -555,7 +555,7 @@ class OrderingTests(trove_testtools.TestCase):
                                                           self.instance_id)
         self.assertIsNone(marker)
         actual = [b.name for b in backups]
-        expected = [u'one', u'two', u'three', u'four']
+        expected = ['one', 'two', 'three', 'four']
         self.assertEqual(expected, actual)
 
 
